// Copyright The OpenTelemetry Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//	http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package internal // import "go.opentelemetry.io/collector/pdata/internal/cmd/pdatagen/internal"

import (
	"path/filepath"
)

var traceOtlpFile = &File{
	Path:        filepath.Join("pdata", "ptrace"),
	Name:        "traces_otlp",
	PackageName: "ptraceotlp",
	imports: []string{
		`"sort"`,
		``,
		`"go.opentelemetry.io/collector/pdata/internal"`,
		`otlpcollectortrace "go.opentelemetry.io/collector/pdata/internal/data/protogen/collector/trace/v1"`,
	},
	testImports: []string{
		`"testing"`,
		``,
		`"github.com/stretchr/testify/assert"`,
		``,
		`"go.opentelemetry.io/collector/pdata/internal"`,
		`otlpcollectortrace "go.opentelemetry.io/collector/pdata/internal/data/protogen/collector/trace/v1"`,
	},
	structs: []baseStruct{
		exportTracePartialSuccess,
	},
}

var exportTracePartialSuccess = &messageValueStruct{
	structName:         "ExportPartialSuccess",
	internalStructName: "TracesExportPartialSuccess",
	description:        "// ExportPartialSuccess represents the details of a partially successful export request.",
	originFullName:     "otlpcollectortrace.ExportTracePartialSuccess",
	fields: []baseField{
		&primitiveField{
			fieldName:  "RejectedSpans",
			returnType: "int64",
			defaultVal: `int64(0)`,
			testVal:    `int64(13)`,
		},
		&primitiveField{
			fieldName:  "ErrorMessage",
			returnType: "string",
			defaultVal: `""`,
			testVal:    `"error message"`,
		},
	},
}
